Class: Google::Apis::FirebaseappdistributionV1::GdataCompositeMedia
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GdataCompositeMedia
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
A sequence of media data references representing composite data. Introduced to support Bigstore composite objects. For details, visit http://go/bigstore- composites.
Instance Attribute Summary collapse
-
#blob_ref ⇒ String
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be the byte representation of a blobstore.BlobRef.
-
#blobstore2_info ⇒ Google::Apis::FirebaseappdistributionV1::GdataBlobstore2Info
Information to read/write to blobstore2.
-
#cosmo_binary_reference ⇒ String
A binary data reference for a media download.
-
#crc32c_hash ⇒ Fixnum
crc32.c hash for the payload.
-
#inline ⇒ String
Media data, set if reference_type is INLINE Corresponds to the JSON property
inlineNOTE: Values are automatically base64 encoded/decoded in the client library. -
#length ⇒ Fixnum
Size of the data, in bytes Corresponds to the JSON property
length. -
#md5_hash ⇒ String
MD5 hash for the payload.
-
#object_id_prop ⇒ Google::Apis::FirebaseappdistributionV1::GdataObjectId
This is a copy of the tech.blob.ObjectId proto, which could not be used directly here due to transitive closure issues with JavaScript support; see http://b/8801763.
-
#path ⇒ String
Path to the data, set if reference_type is PATH Corresponds to the JSON property
path. -
#reference_type ⇒ String
Describes what the field reference contains.
-
#sha1_hash ⇒ String
SHA-1 hash for the payload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GdataCompositeMedia
constructor
A new instance of GdataCompositeMedia.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GdataCompositeMedia
Returns a new instance of GdataCompositeMedia.
169 170 171 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_ref ⇒ String
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be
the byte representation of a blobstore.BlobRef. Since Blobstore is deprecating
v1, use blobstore2_info instead. For now, any v2 blob will also be represented
in this field as v1 BlobRef.
Corresponds to the JSON property blobRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
106 107 108 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 106 def blob_ref @blob_ref end |
#blobstore2_info ⇒ Google::Apis::FirebaseappdistributionV1::GdataBlobstore2Info
Information to read/write to blobstore2.
Corresponds to the JSON property blobstore2Info
111 112 113 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 111 def blobstore2_info @blobstore2_info end |
#cosmo_binary_reference ⇒ String
A binary data reference for a media download. Serves as a technology-agnostic
binary reference in some Google infrastructure. This value is a serialized
storage_cosmo.BinaryReference proto. Storing it as bytes is a hack to get
around the fact that the cosmo proto (as well as others it includes) doesn't
support JavaScript. This prevents us from including the actual type of this
field.
Corresponds to the JSON property cosmoBinaryReference
NOTE: Values are automatically base64 encoded/decoded in the client library.
122 123 124 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 122 def cosmo_binary_reference @cosmo_binary_reference end |
#crc32c_hash ⇒ Fixnum
crc32.c hash for the payload.
Corresponds to the JSON property crc32cHash
127 128 129 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 127 def crc32c_hash @crc32c_hash end |
#inline ⇒ String
Media data, set if reference_type is INLINE
Corresponds to the JSON property inline
NOTE: Values are automatically base64 encoded/decoded in the client library.
133 134 135 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 133 def inline @inline end |
#length ⇒ Fixnum
Size of the data, in bytes
Corresponds to the JSON property length
138 139 140 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 138 def length @length end |
#md5_hash ⇒ String
MD5 hash for the payload.
Corresponds to the JSON property md5Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
144 145 146 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 144 def md5_hash @md5_hash end |
#object_id_prop ⇒ Google::Apis::FirebaseappdistributionV1::GdataObjectId
This is a copy of the tech.blob.ObjectId proto, which could not be used
directly here due to transitive closure issues with JavaScript support; see
http://b/8801763.
Corresponds to the JSON property objectId
151 152 153 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 151 def object_id_prop @object_id_prop end |
#path ⇒ String
Path to the data, set if reference_type is PATH
Corresponds to the JSON property path
156 157 158 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 156 def path @path end |
#reference_type ⇒ String
Describes what the field reference contains.
Corresponds to the JSON property referenceType
161 162 163 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 161 def reference_type @reference_type end |
#sha1_hash ⇒ String
SHA-1 hash for the payload.
Corresponds to the JSON property sha1Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
167 168 169 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 167 def sha1_hash @sha1_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 174 def update!(**args) @blob_ref = args[:blob_ref] if args.key?(:blob_ref) @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info) @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference) @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash) @inline = args[:inline] if args.key?(:inline) @length = args[:length] if args.key?(:length) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @path = args[:path] if args.key?(:path) @reference_type = args[:reference_type] if args.key?(:reference_type) @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash) end |