Class: Google::Apis::FirebaseappdistributionV1::GdataMedia

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

A reference to data stored on the filesystem, on GFS or in blobstore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GdataMedia

Returns a new instance of GdataMedia.



655
656
657
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Deprecated, use one of explicit hash type fields instead. Algorithm used for calculating the hash. As of 2011/01/21, "MD5" is the only possible value for this field. New values may be added at any time. Corresponds to the JSON property algorithm

Returns:

  • (String)


459
460
461
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 459

def algorithm
  @algorithm
end

#bigstore_object_refString

Use object_id instead. Corresponds to the JSON property bigstoreObjectRef NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


465
466
467
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 465

def bigstore_object_ref
  @bigstore_object_ref
end

#blob_refString

Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be the byte representation of a blobstore.BlobRef. Since Blobstore is deprecating v1, use blobstore2_info instead. For now, any v2 blob will also be represented in this field as v1 BlobRef. Corresponds to the JSON property blobRef NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 474

def blob_ref
  @blob_ref
end

#blobstore2_infoGoogle::Apis::FirebaseappdistributionV1::GdataBlobstore2Info

Information to read/write to blobstore2. Corresponds to the JSON property blobstore2Info



479
480
481
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 479

def blobstore2_info
  @blobstore2_info
end

#composite_mediaArray<Google::Apis::FirebaseappdistributionV1::GdataCompositeMedia>

A composite media composed of one or more media objects, set if reference_type is COMPOSITE_MEDIA. The media length field must be set to the sum of the lengths of all composite media objects. Note: All composite media must have length specified. Corresponds to the JSON property compositeMedia



487
488
489
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 487

def composite_media
  @composite_media
end

#content_typeString

MIME type of the data Corresponds to the JSON property contentType

Returns:

  • (String)


492
493
494
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 492

def content_type
  @content_type
end

#content_type_infoGoogle::Apis::FirebaseappdistributionV1::GdataContentTypeInfo

Detailed Content-Type information from Scotty. The Content-Type of the media will typically be filled in by the header or Scotty's best_guess, but this extended information provides the backend with more information so that it can make a better decision if needed. This is only used on media upload requests from Scotty. Corresponds to the JSON property contentTypeInfo



501
502
503
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 501

def content_type_info
  @content_type_info
end

#cosmo_binary_referenceString

A binary data reference for a media download. Serves as a technology-agnostic binary reference in some Google infrastructure. This value is a serialized storage_cosmo.BinaryReference proto. Storing it as bytes is a hack to get around the fact that the cosmo proto (as well as others it includes) doesn't support JavaScript. This prevents us from including the actual type of this field. Corresponds to the JSON property cosmoBinaryReference NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


512
513
514
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 512

def cosmo_binary_reference
  @cosmo_binary_reference
end

#crc32c_hashFixnum

For Scotty Uploads: Scotty-provided hashes for uploads For Scotty Downloads: ( WARNING: DO NOT USE WITHOUT PERMISSION FROM THE SCOTTY TEAM.) A Hash provided by the agent to be used to verify the data being downloaded. Currently only supported for inline payloads. Further, only crc32c_hash is currently supported. Corresponds to the JSON property crc32cHash

Returns:

  • (Fixnum)


521
522
523
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 521

def crc32c_hash
  @crc32c_hash
end

#diff_checksums_responseGoogle::Apis::FirebaseappdistributionV1::GdataDiffChecksumsResponse

Backend response for a Diff get checksums response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol. Corresponds to the JSON property diffChecksumsResponse



527
528
529
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 527

def diff_checksums_response
  @diff_checksums_response
end

#diff_download_responseGoogle::Apis::FirebaseappdistributionV1::GdataDiffDownloadResponse

Backend response for a Diff download response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol. Corresponds to the JSON property diffDownloadResponse



533
534
535
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 533

def diff_download_response
  @diff_download_response
end

#diff_upload_requestGoogle::Apis::FirebaseappdistributionV1::GdataDiffUploadRequest

A Diff upload request. For details on the Scotty Diff protocol, visit http:// go/scotty-diff-protocol. Corresponds to the JSON property diffUploadRequest



539
540
541
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 539

def diff_upload_request
  @diff_upload_request
end

#diff_upload_responseGoogle::Apis::FirebaseappdistributionV1::GdataDiffUploadResponse

Backend response for a Diff upload request. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol. Corresponds to the JSON property diffUploadResponse



545
546
547
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 545

def diff_upload_response
  @diff_upload_response
end

#diff_version_responseGoogle::Apis::FirebaseappdistributionV1::GdataDiffVersionResponse

Backend response for a Diff get version response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol. Corresponds to the JSON property diffVersionResponse



551
552
553
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 551

def diff_version_response
  @diff_version_response
end

#download_parametersGoogle::Apis::FirebaseappdistributionV1::GdataDownloadParameters

Parameters specific to media downloads. Corresponds to the JSON property downloadParameters



556
557
558
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 556

def download_parameters
  @download_parameters
end

#filenameString

Original file name Corresponds to the JSON property filename

Returns:

  • (String)


561
562
563
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 561

def filename
  @filename
end

#hash_propString

Deprecated, use one of explicit hash type fields instead. These two hash related fields will only be populated on Scotty based media uploads and will contain the content of the hash group in the NotificationRequest: http://cs/# google3/blobstore2/api/scotty/service/proto/upload_listener.proto&q=class:Hash Hex encoded hash value of the uploaded media. Corresponds to the JSON property hash

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 570

def hash_prop
  @hash_prop
end

#hash_verifiedBoolean Also known as: hash_verified?

For Scotty uploads only. If a user sends a hash code and the backend has requested that Scotty verify the upload against the client hash, Scotty will perform the check on behalf of the backend and will reject it if the hashes don't match. This is set to true if Scotty performed this verification. Corresponds to the JSON property hashVerified

Returns:

  • (Boolean)


578
579
580
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 578

def hash_verified
  @hash_verified
end

#inlineString

Media data, set if reference_type is INLINE Corresponds to the JSON property inline NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


585
586
587
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 585

def inline
  @inline
end

#is_potential_retryBoolean Also known as: is_potential_retry?

|is_potential_retry| is set false only when Scotty is certain that it has not sent the request before. When a client resumes an upload, this field must be set true in agent calls, because Scotty cannot be certain that it has never sent the request before due to potential failure in the session state persistence. Corresponds to the JSON property isPotentialRetry

Returns:

  • (Boolean)


594
595
596
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 594

def is_potential_retry
  @is_potential_retry
end

#lengthFixnum

Size of the data, in bytes Corresponds to the JSON property length

Returns:

  • (Fixnum)


600
601
602
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 600

def length
  @length
end

#md5_hashString

Scotty-provided MD5 hash for an upload. Corresponds to the JSON property md5Hash NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


606
607
608
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 606

def md5_hash
  @md5_hash
end

#media_idString

Media id to forward to the operation GetMedia. Can be set if reference_type is GET_MEDIA. Corresponds to the JSON property mediaId NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 613

def media_id
  @media_id
end

#object_id_propGoogle::Apis::FirebaseappdistributionV1::GdataObjectId

This is a copy of the tech.blob.ObjectId proto, which could not be used directly here due to transitive closure issues with JavaScript support; see http://b/8801763. Corresponds to the JSON property objectId



620
621
622
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 620

def object_id_prop
  @object_id_prop
end

#pathString

Path to the data, set if reference_type is PATH Corresponds to the JSON property path

Returns:

  • (String)


625
626
627
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 625

def path
  @path
end

#reference_typeString

Describes what the field reference contains. Corresponds to the JSON property referenceType

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 630

def reference_type
  @reference_type
end

#sha1_hashString

Scotty-provided SHA1 hash for an upload. Corresponds to the JSON property sha1Hash NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


636
637
638
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 636

def sha1_hash
  @sha1_hash
end

#sha256_hashString

Scotty-provided SHA256 hash for an upload. Corresponds to the JSON property sha256Hash NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


642
643
644
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 642

def sha256_hash
  @sha256_hash
end

#timestampFixnum

Time at which the media data was last updated, in milliseconds since UNIX epoch Corresponds to the JSON property timestamp

Returns:

  • (Fixnum)


648
649
650
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 648

def timestamp
  @timestamp
end

#tokenString

A unique fingerprint/version id for the media data Corresponds to the JSON property token

Returns:

  • (String)


653
654
655
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 653

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 660

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @bigstore_object_ref = args[:bigstore_object_ref] if args.key?(:bigstore_object_ref)
  @blob_ref = args[:blob_ref] if args.key?(:blob_ref)
  @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info)
  @composite_media = args[:composite_media] if args.key?(:composite_media)
  @content_type = args[:content_type] if args.key?(:content_type)
  @content_type_info = args[:content_type_info] if args.key?(:content_type_info)
  @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference)
  @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash)
  @diff_checksums_response = args[:diff_checksums_response] if args.key?(:diff_checksums_response)
  @diff_download_response = args[:diff_download_response] if args.key?(:diff_download_response)
  @diff_upload_request = args[:diff_upload_request] if args.key?(:diff_upload_request)
  @diff_upload_response = args[:diff_upload_response] if args.key?(:diff_upload_response)
  @diff_version_response = args[:diff_version_response] if args.key?(:diff_version_response)
  @download_parameters = args[:download_parameters] if args.key?(:download_parameters)
  @filename = args[:filename] if args.key?(:filename)
  @hash_prop = args[:hash_prop] if args.key?(:hash_prop)
  @hash_verified = args[:hash_verified] if args.key?(:hash_verified)
  @inline = args[:inline] if args.key?(:inline)
  @is_potential_retry = args[:is_potential_retry] if args.key?(:is_potential_retry)
  @length = args[:length] if args.key?(:length)
  @md5_hash = args[:md5_hash] if args.key?(:md5_hash)
  @media_id = args[:media_id] if args.key?(:media_id)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @path = args[:path] if args.key?(:path)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash)
  @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @token = args[:token] if args.key?(:token)
end