Class: Google::Apis::FirebaseappdistributionV1::GdataObjectId
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GdataObjectId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
This is a copy of the tech.blob.ObjectId proto, which could not be used directly here due to transitive closure issues with JavaScript support; see http://b/8801763.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of the bucket to which this object belongs.
-
#generation ⇒ Fixnum
Generation of the object.
-
#object_name ⇒ String
The name of the object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GdataObjectId
constructor
A new instance of GdataObjectId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GdataObjectId
Returns a new instance of GdataObjectId.
718 719 720 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_name ⇒ String
The name of the bucket to which this object belongs.
Corresponds to the JSON property bucketName
703 704 705 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 703 def bucket_name @bucket_name end |
#generation ⇒ Fixnum
Generation of the object. Generations are monotonically increasing across
writes, allowing them to be be compared to determine which generation is newer.
If this is omitted in a request, then you are requesting the live object. See
http://go/bigstore-versions
Corresponds to the JSON property generation
711 712 713 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 711 def generation @generation end |
#object_name ⇒ String
The name of the object.
Corresponds to the JSON property objectName
716 717 718 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 716 def object_name @object_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
723 724 725 726 727 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 723 def update!(**args) @bucket_name = args[:bucket_name] if args.key?(:bucket_name) @generation = args[:generation] if args.key?(:generation) @object_name = args[:object_name] if args.key?(:object_name) end |