Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

A group which can contain testers. A group can be invited to test apps in a Firebase project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Group

Returns a new instance of GoogleFirebaseAppdistroV1Group.



1040
1041
1042
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The display name of the group. Corresponds to the JSON property displayName

Returns:

  • (String)


1017
1018
1019
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1017

def display_name
  @display_name
end

Output only. The number of invite links for this group. Corresponds to the JSON property inviteLinkCount

Returns:

  • (Fixnum)


1022
1023
1024
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1022

def invite_link_count
  @invite_link_count
end

#nameString

The name of the group resource. Format: projects/project_number/groups/ group_alias` Corresponds to the JSON propertyname`

Returns:

  • (String)


1028
1029
1030
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1028

def name
  @name
end

#release_countFixnum

Output only. The number of releases this group is permitted to access. Corresponds to the JSON property releaseCount

Returns:

  • (Fixnum)


1033
1034
1035
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1033

def release_count
  @release_count
end

#tester_countFixnum

Output only. The number of testers who are members of this group. Corresponds to the JSON property testerCount

Returns:

  • (Fixnum)


1038
1039
1040
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1038

def tester_count
  @tester_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1045
1046
1047
1048
1049
1050
1051
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1045

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @invite_link_count = args[:invite_link_count] if args.key?(:invite_link_count)
  @name = args[:name] if args.key?(:name)
  @release_count = args[:release_count] if args.key?(:release_count)
  @tester_count = args[:tester_count] if args.key?(:tester_count)
end