Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1TestCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

App bundle test certificate

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1TestCertificate

Returns a new instance of GoogleFirebaseAppdistroV1TestCertificate.



1326
1327
1328
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hash_md5String

Hex string of MD5 hash of the test certificate used to resign the AAB Corresponds to the JSON property hashMd5

Returns:

  • (String)


1314
1315
1316
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1314

def hash_md5
  @hash_md5
end

#hash_sha1String

Hex string of SHA1 hash of the test certificate used to resign the AAB Corresponds to the JSON property hashSha1

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1319

def hash_sha1
  @hash_sha1
end

#hash_sha256String

Hex string of SHA256 hash of the test certificate used to resign the AAB Corresponds to the JSON property hashSha256

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1324

def hash_sha256
  @hash_sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1331
1332
1333
1334
1335
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1331

def update!(**args)
  @hash_md5 = args[:hash_md5] if args.key?(:hash_md5)
  @hash_sha1 = args[:hash_sha1] if args.key?(:hash_sha1)
  @hash_sha256 = args[:hash_sha256] if args.key?(:hash_sha256)
end