Class: Google::Apis::FirebaseappdistributionV1::GdataBlobstore2Info
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GdataBlobstore2Info
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
Information to read/write to blobstore2.
Instance Attribute Summary collapse
-
#blob_generation ⇒ Fixnum
The blob generation id.
-
#blob_id ⇒ String
The blob id, e.g., /blobstore/prod/playground/scotty Corresponds to the JSON property
blobId. -
#download_external_read_token ⇒ String
A serialized External Read Token passed from Bigstore -> Scotty for a GCS download.
-
#download_read_handle ⇒ String
Read handle passed from Bigstore -> Scotty for a GCS download.
-
#read_token ⇒ String
The blob read token.
-
#upload_fragment_list_creation_info ⇒ String
A serialized Object Fragment List Creation Info passed from Bigstore -> Scotty for a GCS upload.
-
#upload_metadata_container ⇒ String
Metadata passed from Blobstore -> Scotty for a new GCS upload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GdataBlobstore2Info
constructor
A new instance of GdataBlobstore2Info.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GdataBlobstore2Info
Returns a new instance of GdataBlobstore2Info.
77 78 79 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 77 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_generation ⇒ Fixnum
The blob generation id.
Corresponds to the JSON property blobGeneration
32 33 34 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 32 def blob_generation @blob_generation end |
#blob_id ⇒ String
The blob id, e.g., /blobstore/prod/playground/scotty
Corresponds to the JSON property blobId
37 38 39 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 37 def blob_id @blob_id end |
#download_external_read_token ⇒ String
A serialized External Read Token passed from Bigstore -> Scotty for a GCS
download. This field must never be consumed outside of Bigstore, and is not
applicable to non-GCS media uploads.
Corresponds to the JSON property downloadExternalReadToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
45 46 47 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 45 def download_external_read_token @download_external_read_token end |
#download_read_handle ⇒ String
Read handle passed from Bigstore -> Scotty for a GCS download. This is a
signed, serialized blobstore2.ReadHandle proto which must never be set outside
of Bigstore, and is not applicable to non-GCS media downloads.
Corresponds to the JSON property downloadReadHandle
NOTE: Values are automatically base64 encoded/decoded in the client library.
53 54 55 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 53 def download_read_handle @download_read_handle end |
#read_token ⇒ String
The blob read token. Needed to read blobs that have not been replicated. Might
not be available until the final call.
Corresponds to the JSON property readToken
59 60 61 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 59 def read_token @read_token end |
#upload_fragment_list_creation_info ⇒ String
A serialized Object Fragment List Creation Info passed from Bigstore -> Scotty
for a GCS upload. This field must never be consumed outside of Bigstore, and
is not applicable to non-GCS media uploads.
Corresponds to the JSON property uploadFragmentListCreationInfo
NOTE: Values are automatically base64 encoded/decoded in the client library.
67 68 69 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 67 def upload_fragment_list_creation_info @upload_fragment_list_creation_info end |
#upload_metadata_container ⇒ String
Metadata passed from Blobstore -> Scotty for a new GCS upload. This is a
signed, serialized blobstore2.BlobMetadataContainer proto which must never be
consumed outside of Bigstore, and is not applicable to non-GCS media uploads.
Corresponds to the JSON property uploadMetadataContainer
NOTE: Values are automatically base64 encoded/decoded in the client library.
75 76 77 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 75 def @upload_metadata_container end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 82 def update!(**args) @blob_generation = args[:blob_generation] if args.key?(:blob_generation) @blob_id = args[:blob_id] if args.key?(:blob_id) @download_external_read_token = args[:download_external_read_token] if args.key?(:download_external_read_token) @download_read_handle = args[:download_read_handle] if args.key?(:download_read_handle) @read_token = args[:read_token] if args.key?(:read_token) @upload_fragment_list_creation_info = args[:upload_fragment_list_creation_info] if args.key?(:upload_fragment_list_creation_info) @upload_metadata_container = args[:upload_metadata_container] if args.key?(:upload_metadata_container) end |