Class: Google::Apis::FirebaseappdistributionV1::GdataContentTypeInfo
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GdataContentTypeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
Detailed Content-Type information from Scotty. The Content-Type of the media will typically be filled in by the header or Scotty's best_guess, but this extended information provides the backend with more information so that it can make a better decision if needed. This is only used on media upload requests from Scotty.
Instance Attribute Summary collapse
-
#best_guess ⇒ String
Scotty's best guess of what the content type of the file is.
-
#from_bytes ⇒ String
The content type of the file derived by looking at specific bytes (i.e. "magic bytes") of the actual file.
-
#from_file_name ⇒ String
The content type of the file derived from the file extension of the original file name used by the client.
-
#from_fusion_id ⇒ String
The content type of the file detected by Fusion ID.
-
#from_header ⇒ String
The content type of the file as specified in the request headers, multipart headers, or RUPIO start request.
-
#from_url_path ⇒ String
The content type of the file derived from the file extension of the URL path.
-
#fusion_id_detection_metadata ⇒ String
Metadata information from Fusion ID detection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GdataContentTypeInfo
constructor
A new instance of GdataContentTypeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GdataContentTypeInfo
Returns a new instance of GdataContentTypeInfo.
239 240 241 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_guess ⇒ String
Scotty's best guess of what the content type of the file is.
Corresponds to the JSON property bestGuess
200 201 202 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 200 def best_guess @best_guess end |
#from_bytes ⇒ String
The content type of the file derived by looking at specific bytes (i.e. "magic
bytes") of the actual file.
Corresponds to the JSON property fromBytes
206 207 208 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 206 def from_bytes @from_bytes end |
#from_file_name ⇒ String
The content type of the file derived from the file extension of the original
file name used by the client.
Corresponds to the JSON property fromFileName
212 213 214 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 212 def from_file_name @from_file_name end |
#from_fusion_id ⇒ String
The content type of the file detected by Fusion ID. go/fusionid
Corresponds to the JSON property fromFusionId
217 218 219 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 217 def from_fusion_id @from_fusion_id end |
#from_header ⇒ String
The content type of the file as specified in the request headers, multipart
headers, or RUPIO start request.
Corresponds to the JSON property fromHeader
223 224 225 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 223 def from_header @from_header end |
#from_url_path ⇒ String
The content type of the file derived from the file extension of the URL path.
The URL path is assumed to represent a file name (which is typically only true
for agents that are providing a REST API).
Corresponds to the JSON property fromUrlPath
230 231 232 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 230 def from_url_path @from_url_path end |
#fusion_id_detection_metadata ⇒ String
Metadata information from Fusion ID detection. Serialized
FusionIdDetectionMetadata proto. Only set if from_fusion_id is set.
Corresponds to the JSON property fusionIdDetectionMetadata
NOTE: Values are automatically base64 encoded/decoded in the client library.
237 238 239 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 237 def @fusion_id_detection_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
244 245 246 247 248 249 250 251 252 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 244 def update!(**args) @best_guess = args[:best_guess] if args.key?(:best_guess) @from_bytes = args[:from_bytes] if args.key?(:from_bytes) @from_file_name = args[:from_file_name] if args.key?(:from_file_name) @from_fusion_id = args[:from_fusion_id] if args.key?(:from_fusion_id) @from_header = args[:from_header] if args.key?(:from_header) @from_url_path = args[:from_url_path] if args.key?(:from_url_path) @fusion_id_detection_metadata = args[:fusion_id_detection_metadata] if args.key?(:fusion_id_detection_metadata) end |