Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

A group which can contain testers. A group can be invited to test apps in a Firebase project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Group

Returns a new instance of GoogleFirebaseAppdistroV1Group.



1033
1034
1035
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The display name of the group. Corresponds to the JSON property displayName

Returns:

  • (String)


1010
1011
1012
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1010

def display_name
  @display_name
end

Output only. The number of invite links for this group. Corresponds to the JSON property inviteLinkCount

Returns:

  • (Fixnum)


1015
1016
1017
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1015

def invite_link_count
  @invite_link_count
end

#nameString

The name of the group resource. Format: projects/project_number/groups/ group_alias` Corresponds to the JSON propertyname`

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1021

def name
  @name
end

#release_countFixnum

Output only. The number of releases this group is permitted to access. Corresponds to the JSON property releaseCount

Returns:

  • (Fixnum)


1026
1027
1028
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1026

def release_count
  @release_count
end

#tester_countFixnum

Output only. The number of testers who are members of this group. Corresponds to the JSON property testerCount

Returns:

  • (Fixnum)


1031
1032
1033
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1031

def tester_count
  @tester_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1038
1039
1040
1041
1042
1043
1044
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1038

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @invite_link_count = args[:invite_link_count] if args.key?(:invite_link_count)
  @name = args[:name] if args.key?(:name)
  @release_count = args[:release_count] if args.key?(:release_count)
  @tester_count = args[:tester_count] if args.key?(:tester_count)
end