Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Group
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Group
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
A group which can contain testers. A group can be invited to test apps in a Firebase project.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#invite_link_count ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the group resource.
-
#release_count ⇒ Fixnum
Output only.
-
#tester_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Group
constructor
A new instance of GoogleFirebaseAppdistroV1Group.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Group
Returns a new instance of GoogleFirebaseAppdistroV1Group.
1033 1034 1035 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The display name of the group.
Corresponds to the JSON property displayName
1010 1011 1012 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1010 def display_name @display_name end |
#invite_link_count ⇒ Fixnum
Output only. The number of invite links for this group.
Corresponds to the JSON property inviteLinkCount
1015 1016 1017 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1015 def invite_link_count @invite_link_count end |
#name ⇒ String
The name of the group resource. Format: projects/project_number/groups/
group_alias`
Corresponds to the JSON propertyname`
1021 1022 1023 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1021 def name @name end |
#release_count ⇒ Fixnum
Output only. The number of releases this group is permitted to access.
Corresponds to the JSON property releaseCount
1026 1027 1028 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1026 def release_count @release_count end |
#tester_count ⇒ Fixnum
Output only. The number of testers who are members of this group.
Corresponds to the JSON property testerCount
1031 1032 1033 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1031 def tester_count @tester_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1038 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @invite_link_count = args[:invite_link_count] if args.key?(:invite_link_count) @name = args[:name] if args.key?(:name) @release_count = args[:release_count] if args.key?(:release_count) @tester_count = args[:tester_count] if args.key?(:tester_count) end |