Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Release
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Release
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
A release of a Firebase app.
Instance Attribute Summary collapse
-
#accepted_invitation_count ⇒ Fixnum
Output only.
-
#android_package_registration_state ⇒ String
Output only.
-
#binary_download_uri ⇒ String
Output only.
-
#binary_type ⇒ String
Output only.
-
#build_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#display_version ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#feedback_count ⇒ Fixnum
Output only.
-
#firebase_console_uri ⇒ String
Output only.
-
#installation_count ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the release resource.
-
#open_invitation_count ⇒ Fixnum
Output only.
-
#release_notes ⇒ Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1ReleaseNotes
Notes that belong to a release.
-
#test_state ⇒ String
Output only.
-
#testing_uri ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Release
constructor
A new instance of GoogleFirebaseAppdistroV1Release.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Release
Returns a new instance of GoogleFirebaseAppdistroV1Release.
1262 1263 1264 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted_invitation_count ⇒ Fixnum
Output only. Number of testers with accepted invitations.
Corresponds to the JSON property acceptedInvitationCount
1171 1172 1173 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1171 def accepted_invitation_count @accepted_invitation_count end |
#android_package_registration_state ⇒ String
Output only. Registration state of the Android package (BinaryType.APK).
Corresponds to the JSON property androidPackageRegistrationState
1176 1177 1178 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1176 def android_package_registration_state @android_package_registration_state end |
#binary_download_uri ⇒ String
Output only. A signed link (which expires in one hour) to directly download
the app binary (IPA/APK/AAB) file.
Corresponds to the JSON property binaryDownloadUri
1182 1183 1184 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1182 def binary_download_uri @binary_download_uri end |
#binary_type ⇒ String
Output only. Type of binary.
Corresponds to the JSON property binaryType
1187 1188 1189 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1187 def binary_type @binary_type end |
#build_version ⇒ String
Output only. Build version of the release. For an Android release, the build
version is the versionCode. For an iOS release, the build version is the
CFBundleVersion.
Corresponds to the JSON property buildVersion
1194 1195 1196 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1194 def build_version @build_version end |
#create_time ⇒ String
Output only. The time the release was created.
Corresponds to the JSON property createTime
1199 1200 1201 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1199 def create_time @create_time end |
#display_version ⇒ String
Output only. Display version of the release. For an Android release, the
display version is the versionName. For an iOS release, the display version
is the CFBundleShortVersionString.
Corresponds to the JSON property displayVersion
1206 1207 1208 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1206 def display_version @display_version end |
#expire_time ⇒ String
Output only. The time the release will expire.
Corresponds to the JSON property expireTime
1211 1212 1213 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1211 def expire_time @expire_time end |
#feedback_count ⇒ Fixnum
Output only. Number of feedback reports left by testers.
Corresponds to the JSON property feedbackCount
1216 1217 1218 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1216 def feedback_count @feedback_count end |
#firebase_console_uri ⇒ String
Output only. A link to the Firebase console displaying a single release.
Corresponds to the JSON property firebaseConsoleUri
1221 1222 1223 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1221 def firebase_console_uri @firebase_console_uri end |
#installation_count ⇒ Fixnum
Output only. Number of testers who have downloaded this release.
Corresponds to the JSON property installationCount
1226 1227 1228 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1226 def installation_count @installation_count end |
#name ⇒ String
The name of the release resource. Format: projects/project_number/apps/app
/releases/release`
Corresponds to the JSON propertyname`
1232 1233 1234 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1232 def name @name end |
#open_invitation_count ⇒ Fixnum
Output only. Number of testers who were invited (incl. expired invitations),
but did not (yet) accept the invitation.
Corresponds to the JSON property openInvitationCount
1238 1239 1240 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1238 def open_invitation_count @open_invitation_count end |
#release_notes ⇒ Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1ReleaseNotes
Notes that belong to a release.
Corresponds to the JSON property releaseNotes
1243 1244 1245 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1243 def release_notes @release_notes end |
#test_state ⇒ String
Output only. The overall state of tests run on this release
Corresponds to the JSON property testState
1248 1249 1250 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1248 def test_state @test_state end |
#testing_uri ⇒ String
Output only. A link to the release in the tester web clip or Android app that
lets testers (which were granted access to the app) view release notes and
install the app onto their devices.
Corresponds to the JSON property testingUri
1255 1256 1257 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1255 def testing_uri @testing_uri end |
#update_time ⇒ String
Output only. The time the release was last updated.
Corresponds to the JSON property updateTime
1260 1261 1262 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1260 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1267 def update!(**args) @accepted_invitation_count = args[:accepted_invitation_count] if args.key?(:accepted_invitation_count) @android_package_registration_state = args[:android_package_registration_state] if args.key?(:android_package_registration_state) @binary_download_uri = args[:binary_download_uri] if args.key?(:binary_download_uri) @binary_type = args[:binary_type] if args.key?(:binary_type) @build_version = args[:build_version] if args.key?(:build_version) @create_time = args[:create_time] if args.key?(:create_time) @display_version = args[:display_version] if args.key?(:display_version) @expire_time = args[:expire_time] if args.key?(:expire_time) @feedback_count = args[:feedback_count] if args.key?(:feedback_count) @firebase_console_uri = args[:firebase_console_uri] if args.key?(:firebase_console_uri) @installation_count = args[:installation_count] if args.key?(:installation_count) @name = args[:name] if args.key?(:name) @open_invitation_count = args[:open_invitation_count] if args.key?(:open_invitation_count) @release_notes = args[:release_notes] if args.key?(:release_notes) @test_state = args[:test_state] if args.key?(:test_state) @testing_uri = args[:testing_uri] if args.key?(:testing_uri) @update_time = args[:update_time] if args.key?(:update_time) end |