Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Release

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

A release of a Firebase app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Release

Returns a new instance of GoogleFirebaseAppdistroV1Release.



1231
1232
1233
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_package_registration_stateString

Output only. Registration state of the Android package (BinaryType.APK). Corresponds to the JSON property androidPackageRegistrationState

Returns:

  • (String)


1171
1172
1173
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1171

def android_package_registration_state
  @android_package_registration_state
end

#binary_download_uriString

Output only. A signed link (which expires in one hour) to directly download the app binary (IPA/APK/AAB) file. Corresponds to the JSON property binaryDownloadUri

Returns:

  • (String)


1177
1178
1179
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1177

def binary_download_uri
  @binary_download_uri
end

#build_versionString

Output only. Build version of the release. For an Android release, the build version is the versionCode. For an iOS release, the build version is the CFBundleVersion. Corresponds to the JSON property buildVersion

Returns:

  • (String)


1184
1185
1186
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1184

def build_version
  @build_version
end

#create_timeString

Output only. The time the release was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1189

def create_time
  @create_time
end

#display_versionString

Output only. Display version of the release. For an Android release, the display version is the versionName. For an iOS release, the display version is the CFBundleShortVersionString. Corresponds to the JSON property displayVersion

Returns:

  • (String)


1196
1197
1198
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1196

def display_version
  @display_version
end

#expire_timeString

Output only. The time the release will expire. Corresponds to the JSON property expireTime

Returns:

  • (String)


1201
1202
1203
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1201

def expire_time
  @expire_time
end

#firebase_console_uriString

Output only. A link to the Firebase console displaying a single release. Corresponds to the JSON property firebaseConsoleUri

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1206

def firebase_console_uri
  @firebase_console_uri
end

#nameString

The name of the release resource. Format: projects/project_number/apps/app /releases/release` Corresponds to the JSON propertyname`

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1212

def name
  @name
end

#release_notesGoogle::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1ReleaseNotes

Notes that belong to a release. Corresponds to the JSON property releaseNotes



1217
1218
1219
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1217

def release_notes
  @release_notes
end

#testing_uriString

Output only. A link to the release in the tester web clip or Android app that lets testers (which were granted access to the app) view release notes and install the app onto their devices. Corresponds to the JSON property testingUri

Returns:

  • (String)


1224
1225
1226
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1224

def testing_uri
  @testing_uri
end

#update_timeString

Output only. The time the release was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1229
1230
1231
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1229

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1236

def update!(**args)
  @android_package_registration_state = args[:android_package_registration_state] if args.key?(:android_package_registration_state)
  @binary_download_uri = args[:binary_download_uri] if args.key?(:binary_download_uri)
  @build_version = args[:build_version] if args.key?(:build_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_version = args[:display_version] if args.key?(:display_version)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @firebase_console_uri = args[:firebase_console_uri] if args.key?(:firebase_console_uri)
  @name = args[:name] if args.key?(:name)
  @release_notes = args[:release_notes] if args.key?(:release_notes)
  @testing_uri = args[:testing_uri] if args.key?(:testing_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end