Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1TestCertificate
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1TestCertificate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb
Overview
App bundle test certificate
Instance Attribute Summary collapse
-
#hash_md5 ⇒ String
Hex string of MD5 hash of the test certificate used to resign the AAB Corresponds to the JSON property
hashMd5. -
#hash_sha1 ⇒ String
Hex string of SHA1 hash of the test certificate used to resign the AAB Corresponds to the JSON property
hashSha1. -
#hash_sha256 ⇒ String
Hex string of SHA256 hash of the test certificate used to resign the AAB Corresponds to the JSON property
hashSha256.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1TestCertificate
constructor
A new instance of GoogleFirebaseAppdistroV1TestCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1TestCertificate
Returns a new instance of GoogleFirebaseAppdistroV1TestCertificate.
1270 1271 1272 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hash_md5 ⇒ String
Hex string of MD5 hash of the test certificate used to resign the AAB
Corresponds to the JSON property hashMd5
1258 1259 1260 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1258 def hash_md5 @hash_md5 end |
#hash_sha1 ⇒ String
Hex string of SHA1 hash of the test certificate used to resign the AAB
Corresponds to the JSON property hashSha1
1263 1264 1265 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1263 def hash_sha1 @hash_sha1 end |
#hash_sha256 ⇒ String
Hex string of SHA256 hash of the test certificate used to resign the AAB
Corresponds to the JSON property hashSha256
1268 1269 1270 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1268 def hash_sha256 @hash_sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1275 1276 1277 1278 1279 |
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1275 def update!(**args) @hash_md5 = args[:hash_md5] if args.key?(:hash_md5) @hash_sha1 = args[:hash_sha1] if args.key?(:hash_sha1) @hash_sha256 = args[:hash_sha256] if args.key?(:hash_sha256) end |