Class: Google::Apis::FirebaseappdistributionV1::GoogleFirebaseAppdistroV1Tester

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1/classes.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb,
lib/google/apis/firebaseappdistribution_v1/representations.rb

Overview

A person that can be invited to test apps in a Firebase project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Tester

Returns a new instance of GoogleFirebaseAppdistroV1Tester.



1310
1311
1312
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The name of the tester associated with the Google account used to accept the tester invitation. Corresponds to the JSON property displayName

Returns:

  • (String)


1290
1291
1292
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1290

def display_name
  @display_name
end

#groupsArray<String>

The resource names of the groups this tester belongs to. Corresponds to the JSON property groups

Returns:

  • (Array<String>)


1295
1296
1297
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1295

def groups
  @groups
end

#last_activity_timeString

Output only. The time the tester was last active. This is the most recent time the tester installed one of the apps. If they've never installed one or if the release no longer exists, this is the time the tester was added to the project. Corresponds to the JSON property lastActivityTime

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1302

def last_activity_time
  @last_activity_time
end

#nameString

The name of the tester resource. Format: projects/project_number/testers/ email_address` Corresponds to the JSON propertyname`

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1308

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1315
1316
1317
1318
1319
1320
# File 'lib/google/apis/firebaseappdistribution_v1/classes.rb', line 1315

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @groups = args[:groups] if args.key?(:groups)
  @last_activity_time = args[:last_activity_time] if args.key?(:last_activity_time)
  @name = args[:name] if args.key?(:name)
end